# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.volume_mute import VolumeMute
from mozart_api.models.volume_level import VolumeLevel

from mozart_api.configuration import Configuration


class VolumeState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "default": "VolumeLevel",
        "level": "VolumeLevel",
        "maximum": "VolumeLevel",
        "muted": "VolumeMute",
    }

    attribute_map = {
        "default": "default",
        "level": "level",
        "maximum": "maximum",
        "muted": "muted",
    }

    def __init__(
        self,
        default: Optional[VolumeLevel] = None,
        level: Optional[VolumeLevel] = None,
        maximum: Optional[VolumeLevel] = None,
        muted: Optional[VolumeMute] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """VolumeState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default = None
        self._level = None
        self._maximum = None
        self._muted = None
        self.discriminator = None

        if default is not None:
            self.default = default
        if level is not None:
            self.level = level
        if maximum is not None:
            self.maximum = maximum
        if muted is not None:
            self.muted = muted

    @property
    def default(self):
        # type: () -> VolumeLevel
        """Gets the default of this VolumeState.  # noqa: E501


        :return: The default of this VolumeState.  # noqa: E501
        :rtype: VolumeLevel
        """
        return self._default

    @default.setter
    def default(self, default):
        # type: (VolumeLevel) -> None
        """Sets the default of this VolumeState.


        :param default: The default of this VolumeState.  # noqa: E501
        :type default: VolumeLevel
        :rtype: None
        """

        self._default = default

    @property
    def level(self):
        # type: () -> VolumeLevel
        """Gets the level of this VolumeState.  # noqa: E501


        :return: The level of this VolumeState.  # noqa: E501
        :rtype: VolumeLevel
        """
        return self._level

    @level.setter
    def level(self, level):
        # type: (VolumeLevel) -> None
        """Sets the level of this VolumeState.


        :param level: The level of this VolumeState.  # noqa: E501
        :type level: VolumeLevel
        :rtype: None
        """

        self._level = level

    @property
    def maximum(self):
        # type: () -> VolumeLevel
        """Gets the maximum of this VolumeState.  # noqa: E501


        :return: The maximum of this VolumeState.  # noqa: E501
        :rtype: VolumeLevel
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        # type: (VolumeLevel) -> None
        """Sets the maximum of this VolumeState.


        :param maximum: The maximum of this VolumeState.  # noqa: E501
        :type maximum: VolumeLevel
        :rtype: None
        """

        self._maximum = maximum

    @property
    def muted(self):
        # type: () -> VolumeMute
        """Gets the muted of this VolumeState.  # noqa: E501


        :return: The muted of this VolumeState.  # noqa: E501
        :rtype: VolumeMute
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        # type: (VolumeMute) -> None
        """Sets the muted of this VolumeState.


        :param muted: The muted of this VolumeState.  # noqa: E501
        :type muted: VolumeMute
        :rtype: None
        """

        self._muted = muted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.web_socket_event_sound_settings import (
    WebSocketEventSoundSettings,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestWebSocketEventSoundSettings(unittest.TestCase):
    """WebSocketEventSoundSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebSocketEventSoundSettings
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.web_socket_event_sound_settings.WebSocketEventSoundSettings()  # noqa: E501
        if include_optional:
            return WebSocketEventSoundSettings(
                event_data=mozart_api.models.sound_settings.SoundSettings(
                    adjustments=mozart_api.models.sound_adjustments.SoundAdjustments(
                        ambience=1.337,
                        bass=56,
                        directivity="0",
                        eco_mode=True,
                        fadein=True,
                        loudness=True,
                        treble=56,
                    ),
                    room_compensation=mozart_api.models.room_compensation_info.RoomCompensationInfo(
                        debug=mozart_api.models.room_compensation_debug.RoomCompensationDebug(
                            value=True,
                        ),
                        enabled=mozart_api.models.room_compensation_enabled.RoomCompensationEnabled(
                            value=True,
                        ),
                        last_result=mozart_api.models.room_compensation_result.RoomCompensationResult(
                            compensation=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            measured_response=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            placement="free",
                            reference_response=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            speaker_group_suggestion=mozart_api.models.speaker_group.SpeakerGroup(
                                crossover_frequency=20,
                                enable_phase_compensation=True,
                                friendly_name="0",
                                id="0",
                                is_deleteable=True,
                                items=[
                                    mozart_api.models.speaker_group_member.SpeakerGroupMember(
                                        distance=0,
                                        friendly_name="0",
                                        gain=-24,
                                        id="0",
                                        location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                                            x=56,
                                            y=56,
                                            z=56,
                                        ),
                                        redirection_level=-100,
                                        role="0",
                                        type="0",
                                    )
                                ],
                                room_compensation_id="0",
                                speaker_preset=0,
                            ),
                            time_stamp=datetime.datetime.strptime(
                                "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                            ),
                        ),
                        last_run=null,
                        type=mozart_api.models.room_compensation_type.RoomCompensationType(
                            value="simple",
                        ),
                        version=mozart_api.models.room_compensation_version.RoomCompensationVersion(
                            algorithm=0,
                            coefficients=0,
                        ),
                    ),
                    tone_touch=mozart_api.models.sound_tone_touch.SoundToneTouch(
                        x=1.337,
                        y=1.337,
                        z=1.337,
                    ),
                ),
                event_type="0",
            )
        else:
            return WebSocketEventSoundSettings()

    def testWebSocketEventSoundSettings(self):
        """Test WebSocketEventSoundSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.overlay_play_request_from_usb_from_usb import (
    OverlayPlayRequestFromUsbFromUsb,
)
from mozart_api.models.uri import Uri
from mozart_api.models.overlay_play_request_text_to_speech_text_to_speech import (
    OverlayPlayRequestTextToSpeechTextToSpeech,
)

from mozart_api.configuration import Configuration


class OverlayPlayRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "volume_absolute": "int",
        "uri": "Uri",
        "text_to_speech": "OverlayPlayRequestTextToSpeechTextToSpeech",
        "from_usb": "OverlayPlayRequestFromUsbFromUsb",
    }

    attribute_map = {
        "volume_absolute": "volumeAbsolute",
        "uri": "uri",
        "text_to_speech": "textToSpeech",
        "from_usb": "fromUsb",
    }

    def __init__(
        self,
        volume_absolute: Optional[int] = None,
        uri: Optional[Uri] = None,
        text_to_speech: Optional[OverlayPlayRequestTextToSpeechTextToSpeech] = None,
        from_usb: Optional[OverlayPlayRequestFromUsbFromUsb] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """OverlayPlayRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._volume_absolute = None
        self._uri = None
        self._text_to_speech = None
        self._from_usb = None
        self.discriminator = None

        self.volume_absolute = volume_absolute
        if uri is not None:
            self.uri = uri
        if text_to_speech is not None:
            self.text_to_speech = text_to_speech
        if from_usb is not None:
            self.from_usb = from_usb

    @property
    def volume_absolute(self):
        # type: () -> int
        """Gets the volume_absolute of this OverlayPlayRequest.  # noqa: E501

        An optional absolute volume level at which to play the URI. If not provided, the URI will play at the currently configured volume level on the product. The level should be provided in volume steps [0, 100]   # noqa: E501

        :return: The volume_absolute of this OverlayPlayRequest.  # noqa: E501
        :rtype: int
        """
        return self._volume_absolute

    @volume_absolute.setter
    def volume_absolute(self, volume_absolute):
        # type: (int) -> None
        """Sets the volume_absolute of this OverlayPlayRequest.

        An optional absolute volume level at which to play the URI. If not provided, the URI will play at the currently configured volume level on the product. The level should be provided in volume steps [0, 100]   # noqa: E501

        :param volume_absolute: The volume_absolute of this OverlayPlayRequest.  # noqa: E501
        :type volume_absolute: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and volume_absolute is not None
            and volume_absolute > 100
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_absolute`, must be a value less than or equal to `100`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and volume_absolute is not None
            and volume_absolute < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_absolute`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._volume_absolute = volume_absolute

    @property
    def uri(self):
        # type: () -> Uri
        """Gets the uri of this OverlayPlayRequest.  # noqa: E501


        :return: The uri of this OverlayPlayRequest.  # noqa: E501
        :rtype: Uri
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (Uri) -> None
        """Sets the uri of this OverlayPlayRequest.


        :param uri: The uri of this OverlayPlayRequest.  # noqa: E501
        :type uri: Uri
        :rtype: None
        """

        self._uri = uri

    @property
    def text_to_speech(self):
        # type: () -> OverlayPlayRequestTextToSpeechTextToSpeech
        """Gets the text_to_speech of this OverlayPlayRequest.  # noqa: E501


        :return: The text_to_speech of this OverlayPlayRequest.  # noqa: E501
        :rtype: OverlayPlayRequestTextToSpeechTextToSpeech
        """
        return self._text_to_speech

    @text_to_speech.setter
    def text_to_speech(self, text_to_speech):
        # type: (OverlayPlayRequestTextToSpeechTextToSpeech) -> None
        """Sets the text_to_speech of this OverlayPlayRequest.


        :param text_to_speech: The text_to_speech of this OverlayPlayRequest.  # noqa: E501
        :type text_to_speech: OverlayPlayRequestTextToSpeechTextToSpeech
        :rtype: None
        """

        self._text_to_speech = text_to_speech

    @property
    def from_usb(self):
        # type: () -> OverlayPlayRequestFromUsbFromUsb
        """Gets the from_usb of this OverlayPlayRequest.  # noqa: E501


        :return: The from_usb of this OverlayPlayRequest.  # noqa: E501
        :rtype: OverlayPlayRequestFromUsbFromUsb
        """
        return self._from_usb

    @from_usb.setter
    def from_usb(self, from_usb):
        # type: (OverlayPlayRequestFromUsbFromUsb) -> None
        """Sets the from_usb of this OverlayPlayRequest.


        :param from_usb: The from_usb of this OverlayPlayRequest.  # noqa: E501
        :type from_usb: OverlayPlayRequestFromUsbFromUsb
        :rtype: None
        """

        self._from_usb = from_usb

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OverlayPlayRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OverlayPlayRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.speaker_group_member import SpeakerGroupMember

from mozart_api.configuration import Configuration


class SpeakerGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "crossover_frequency": "int",
        "enable_phase_compensation": "bool",
        "friendly_name": "str",
        "id": "str",
        "is_deleteable": "bool",
        "items": "list[SpeakerGroupMember]",
        "room_compensation_id": "str",
        "speaker_preset": "int",
    }

    attribute_map = {
        "crossover_frequency": "crossoverFrequency",
        "enable_phase_compensation": "enablePhaseCompensation",
        "friendly_name": "friendlyName",
        "id": "id",
        "is_deleteable": "isDeleteable",
        "items": "items",
        "room_compensation_id": "roomCompensationId",
        "speaker_preset": "speakerPreset",
    }

    def __init__(
        self,
        crossover_frequency: Optional[int] = None,
        enable_phase_compensation: Optional[bool] = None,
        friendly_name: Optional[str] = None,
        id: Optional[str] = None,
        is_deleteable: Optional[bool] = None,
        items: Optional[List[SpeakerGroupMember]] = None,
        room_compensation_id: Optional[str] = None,
        speaker_preset: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SpeakerGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._crossover_frequency = None
        self._enable_phase_compensation = None
        self._friendly_name = None
        self._id = None
        self._is_deleteable = None
        self._items = None
        self._room_compensation_id = None
        self._speaker_preset = None
        self.discriminator = None

        self.crossover_frequency = crossover_frequency
        self.enable_phase_compensation = enable_phase_compensation
        self.friendly_name = friendly_name
        if id is not None:
            self.id = id
        self.is_deleteable = is_deleteable
        self.items = items
        self.room_compensation_id = room_compensation_id
        self.speaker_preset = speaker_preset

    @property
    def crossover_frequency(self):
        # type: () -> int
        """Gets the crossover_frequency of this SpeakerGroup.  # noqa: E501

        Crossover frequency for bass management in Hz  # noqa: E501

        :return: The crossover_frequency of this SpeakerGroup.  # noqa: E501
        :rtype: int
        """
        return self._crossover_frequency

    @crossover_frequency.setter
    def crossover_frequency(self, crossover_frequency):
        # type: (int) -> None
        """Sets the crossover_frequency of this SpeakerGroup.

        Crossover frequency for bass management in Hz  # noqa: E501

        :param crossover_frequency: The crossover_frequency of this SpeakerGroup.  # noqa: E501
        :type crossover_frequency: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and crossover_frequency is not None
            and crossover_frequency > 300
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `crossover_frequency`, must be a value less than or equal to `300`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and crossover_frequency is not None
            and crossover_frequency < 20
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `crossover_frequency`, must be a value greater than or equal to `20`"
            )  # noqa: E501

        self._crossover_frequency = crossover_frequency

    @property
    def enable_phase_compensation(self):
        # type: () -> bool
        """Gets the enable_phase_compensation of this SpeakerGroup.  # noqa: E501

        Enable phase compensation in bass management.  # noqa: E501

        :return: The enable_phase_compensation of this SpeakerGroup.  # noqa: E501
        :rtype: bool
        """
        return self._enable_phase_compensation

    @enable_phase_compensation.setter
    def enable_phase_compensation(self, enable_phase_compensation):
        # type: (bool) -> None
        """Sets the enable_phase_compensation of this SpeakerGroup.

        Enable phase compensation in bass management.  # noqa: E501

        :param enable_phase_compensation: The enable_phase_compensation of this SpeakerGroup.  # noqa: E501
        :type enable_phase_compensation: bool
        :rtype: None
        """

        self._enable_phase_compensation = enable_phase_compensation

    @property
    def friendly_name(self):
        # type: () -> str
        """Gets the friendly_name of this SpeakerGroup.  # noqa: E501

        Friendly name of the SpeakerGroup. Required when creating a new group   # noqa: E501

        :return: The friendly_name of this SpeakerGroup.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        # type: (str) -> None
        """Sets the friendly_name of this SpeakerGroup.

        Friendly name of the SpeakerGroup. Required when creating a new group   # noqa: E501

        :param friendly_name: The friendly_name of this SpeakerGroup.  # noqa: E501
        :type friendly_name: str
        :rtype: None
        """

        self._friendly_name = friendly_name

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this SpeakerGroup.  # noqa: E501


        :return: The id of this SpeakerGroup.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (str) -> None
        """Sets the id of this SpeakerGroup.


        :param id: The id of this SpeakerGroup.  # noqa: E501
        :type id: str
        :rtype: None
        """

        self._id = id

    @property
    def is_deleteable(self):
        # type: () -> bool
        """Gets the is_deleteable of this SpeakerGroup.  # noqa: E501


        :return: The is_deleteable of this SpeakerGroup.  # noqa: E501
        :rtype: bool
        """
        return self._is_deleteable

    @is_deleteable.setter
    def is_deleteable(self, is_deleteable):
        # type: (bool) -> None
        """Sets the is_deleteable of this SpeakerGroup.


        :param is_deleteable: The is_deleteable of this SpeakerGroup.  # noqa: E501
        :type is_deleteable: bool
        :rtype: None
        """

        self._is_deleteable = is_deleteable

    @property
    def items(self):
        # type: () -> List[SpeakerGroupMember]
        """Gets the items of this SpeakerGroup.  # noqa: E501


        :return: The items of this SpeakerGroup.  # noqa: E501
        :rtype: List[SpeakerGroupMember]
        """
        return self._items

    @items.setter
    def items(self, items):
        # type: (list[SpeakerGroupMember]) -> None
        """Sets the items of this SpeakerGroup.


        :param items: The items of this SpeakerGroup.  # noqa: E501
        :type items: list[SpeakerGroupMember]
        :rtype: None
        """

        self._items = items

    @property
    def room_compensation_id(self):
        # type: () -> str
        """Gets the room_compensation_id of this SpeakerGroup.  # noqa: E501

        ID of the calculated coefficents for this group, made during advanced room compensation. When updating an existing group, an empty string will clear roomCompensationId.   # noqa: E501

        :return: The room_compensation_id of this SpeakerGroup.  # noqa: E501
        :rtype: str
        """
        return self._room_compensation_id

    @room_compensation_id.setter
    def room_compensation_id(self, room_compensation_id):
        # type: (str) -> None
        """Sets the room_compensation_id of this SpeakerGroup.

        ID of the calculated coefficents for this group, made during advanced room compensation. When updating an existing group, an empty string will clear roomCompensationId.   # noqa: E501

        :param room_compensation_id: The room_compensation_id of this SpeakerGroup.  # noqa: E501
        :type room_compensation_id: str
        :rtype: None
        """

        self._room_compensation_id = room_compensation_id

    @property
    def speaker_preset(self):
        # type: () -> int
        """Gets the speaker_preset of this SpeakerGroup.  # noqa: E501

        Speaker preset / listening mode eg. BL28 curtain position etc.  # noqa: E501

        :return: The speaker_preset of this SpeakerGroup.  # noqa: E501
        :rtype: int
        """
        return self._speaker_preset

    @speaker_preset.setter
    def speaker_preset(self, speaker_preset):
        # type: (int) -> None
        """Sets the speaker_preset of this SpeakerGroup.

        Speaker preset / listening mode eg. BL28 curtain position etc.  # noqa: E501

        :param speaker_preset: The speaker_preset of this SpeakerGroup.  # noqa: E501
        :type speaker_preset: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and speaker_preset is not None
            and speaker_preset > 99
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `speaker_preset`, must be a value less than or equal to `99`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and speaker_preset is not None
            and speaker_preset < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `speaker_preset`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._speaker_preset = speaker_preset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpeakerGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SpeakerGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.software_update_state import SoftwareUpdateState

from mozart_api.configuration import Configuration


class SoftwareUpdateStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "available_update": "str",
        "last_check": "datetime",
        "last_update": "datetime",
        "software_version": "str",
        "state": "SoftwareUpdateState",
        "update_progress": "int",
    }

    attribute_map = {
        "available_update": "availableUpdate",
        "last_check": "lastCheck",
        "last_update": "lastUpdate",
        "software_version": "softwareVersion",
        "state": "state",
        "update_progress": "updateProgress",
    }

    def __init__(
        self,
        available_update: Optional[str] = None,
        last_check: Optional[datetime] = None,
        last_update: Optional[datetime] = None,
        software_version: Optional[str] = None,
        state: Optional[SoftwareUpdateState] = None,
        update_progress: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SoftwareUpdateStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._available_update = None
        self._last_check = None
        self._last_update = None
        self._software_version = None
        self._state = None
        self._update_progress = None
        self.discriminator = None

        if available_update is not None:
            self.available_update = available_update
        if last_check is not None:
            self.last_check = last_check
        if last_update is not None:
            self.last_update = last_update
        self.software_version = software_version
        self.state = state
        if update_progress is not None:
            self.update_progress = update_progress

    @property
    def available_update(self):
        # type: () -> str
        """Gets the available_update of this SoftwareUpdateStatus.  # noqa: E501


        :return: The available_update of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: str
        """
        return self._available_update

    @available_update.setter
    def available_update(self, available_update):
        # type: (str) -> None
        """Sets the available_update of this SoftwareUpdateStatus.


        :param available_update: The available_update of this SoftwareUpdateStatus.  # noqa: E501
        :type available_update: str
        :rtype: None
        """

        self._available_update = available_update

    @property
    def last_check(self):
        # type: () -> datetime
        """Gets the last_check of this SoftwareUpdateStatus.  # noqa: E501


        :return: The last_check of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_check

    @last_check.setter
    def last_check(self, last_check):
        # type: (datetime) -> None
        """Sets the last_check of this SoftwareUpdateStatus.


        :param last_check: The last_check of this SoftwareUpdateStatus.  # noqa: E501
        :type last_check: datetime
        :rtype: None
        """

        self._last_check = last_check

    @property
    def last_update(self):
        # type: () -> datetime
        """Gets the last_update of this SoftwareUpdateStatus.  # noqa: E501


        :return: The last_update of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update

    @last_update.setter
    def last_update(self, last_update):
        # type: (datetime) -> None
        """Sets the last_update of this SoftwareUpdateStatus.


        :param last_update: The last_update of this SoftwareUpdateStatus.  # noqa: E501
        :type last_update: datetime
        :rtype: None
        """

        self._last_update = last_update

    @property
    def software_version(self):
        # type: () -> str
        """Gets the software_version of this SoftwareUpdateStatus.  # noqa: E501


        :return: The software_version of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        # type: (str) -> None
        """Sets the software_version of this SoftwareUpdateStatus.


        :param software_version: The software_version of this SoftwareUpdateStatus.  # noqa: E501
        :type software_version: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and software_version is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `software_version`, must not be `None`"
            )  # noqa: E501

        self._software_version = software_version

    @property
    def state(self):
        # type: () -> SoftwareUpdateState
        """Gets the state of this SoftwareUpdateStatus.  # noqa: E501


        :return: The state of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: SoftwareUpdateState
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: (SoftwareUpdateState) -> None
        """Sets the state of this SoftwareUpdateStatus.


        :param state: The state of this SoftwareUpdateStatus.  # noqa: E501
        :type state: SoftwareUpdateState
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and state is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `state`, must not be `None`"
            )  # noqa: E501

        self._state = state

    @property
    def update_progress(self):
        # type: () -> int
        """Gets the update_progress of this SoftwareUpdateStatus.  # noqa: E501


        :return: The update_progress of this SoftwareUpdateStatus.  # noqa: E501
        :rtype: int
        """
        return self._update_progress

    @update_progress.setter
    def update_progress(self, update_progress):
        # type: (int) -> None
        """Sets the update_progress of this SoftwareUpdateStatus.


        :param update_progress: The update_progress of this SoftwareUpdateStatus.  # noqa: E501
        :type update_progress: int
        :rtype: None
        """

        self._update_progress = update_progress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SoftwareUpdateStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SoftwareUpdateStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class RoomCompensationRange(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"default": "list[str]", "max_items": "int", "range": "list[str]"}

    attribute_map = {"default": "default", "max_items": "maxItems", "range": "range"}

    def __init__(
        self,
        default: Optional[List[str]] = None,
        max_items: Optional[int] = None,
        range: Optional[List[str]] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationRange - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default = None
        self._max_items = None
        self._range = None
        self.discriminator = None

        self.default = default
        if max_items is not None:
            self.max_items = max_items
        self.range = range

    @property
    def default(self):
        # type: () -> List[str]
        """Gets the default of this RoomCompensationRange.  # noqa: E501

        List of room compensation sweeps to combine. No room compensation is done if this list is empty. The maximum length of this list is product specific.   # noqa: E501

        :return: The default of this RoomCompensationRange.  # noqa: E501
        :rtype: List[str]
        """
        return self._default

    @default.setter
    def default(self, default):
        # type: (list[str]) -> None
        """Sets the default of this RoomCompensationRange.

        List of room compensation sweeps to combine. No room compensation is done if this list is empty. The maximum length of this list is product specific.   # noqa: E501

        :param default: The default of this RoomCompensationRange.  # noqa: E501
        :type default: list[str]
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and default is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `default`, must not be `None`"
            )  # noqa: E501

        self._default = default

    @property
    def max_items(self):
        # type: () -> int
        """Gets the max_items of this RoomCompensationRange.  # noqa: E501

        Maximum number of items in the `value` field  # noqa: E501

        :return: The max_items of this RoomCompensationRange.  # noqa: E501
        :rtype: int
        """
        return self._max_items

    @max_items.setter
    def max_items(self, max_items):
        # type: (int) -> None
        """Sets the max_items of this RoomCompensationRange.

        Maximum number of items in the `value` field  # noqa: E501

        :param max_items: The max_items of this RoomCompensationRange.  # noqa: E501
        :type max_items: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and max_items is not None
            and max_items > 20
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `max_items`, must be a value less than or equal to `20`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and max_items is not None
            and max_items < 1
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `max_items`, must be a value greater than or equal to `1`"
            )  # noqa: E501

        self._max_items = max_items

    @property
    def range(self):
        # type: () -> List[str]
        """Gets the range of this RoomCompensationRange.  # noqa: E501

        Possible values for the `value` field  # noqa: E501

        :return: The range of this RoomCompensationRange.  # noqa: E501
        :rtype: List[str]
        """
        return self._range

    @range.setter
    def range(self, range):
        # type: (list[str]) -> None
        """Sets the range of this RoomCompensationRange.

        Possible values for the `value` field  # noqa: E501

        :param range: The range of this RoomCompensationRange.  # noqa: E501
        :type range: list[str]
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and range is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `range`, must not be `None`"
            )  # noqa: E501

        self._range = range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationRange):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationRange):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class RoomCompensationProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "value": "str",
        "action": "str",
        "continue_on_error": "bool",
        "skip_automatic_role_assignment": "bool",
        "speaker_list": "list[str]",
        "speaker_preset": "int",
    }

    attribute_map = {
        "value": "value",
        "action": "action",
        "continue_on_error": "continueOnError",
        "skip_automatic_role_assignment": "skipAutomaticRoleAssignment",
        "speaker_list": "speakerList",
        "speaker_preset": "speakerPreset",
    }

    def __init__(
        self,
        value: Optional["RoomCompensationProperties.LTypeValue"] = None,
        action: Optional[str] = None,
        continue_on_error: Optional[bool] = None,
        skip_automatic_role_assignment: Optional[bool] = None,
        speaker_list: Optional[List[str]] = None,
        speaker_preset: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._value = None
        self._action = None
        self._continue_on_error = None
        self._skip_automatic_role_assignment = None
        self._speaker_list = None
        self._speaker_preset = None
        self.discriminator = None

        if value is not None:
            self.value = value
        self.action = action
        self.continue_on_error = continue_on_error
        self.skip_automatic_role_assignment = skip_automatic_role_assignment
        self.speaker_list = speaker_list
        self.speaker_preset = speaker_preset

    LTypeValue = Literal["simple", "advanced"]

    @property
    def value(self):
        # type: () -> 'RoomCompensationProperties.LTypeValue'
        """Gets the value of this RoomCompensationProperties.  # noqa: E501

        The type of roomcompensation used / to use. simple:   For speakers without external speakers. advanced:   For products with external speakers or other advanced multichannel capabilities.   This requries that at least action in the other properties of RoomCompensationProperties is set.   # noqa: E501

        :return: The value of this RoomCompensationProperties.  # noqa: E501
        :rtype: 'RoomCompensationProperties.LTypeValue'
        """
        return self._value

    @value.setter
    def value(self, value):
        # type: ('RoomCompensationProperties.LTypeValue') -> None
        """Sets the value of this RoomCompensationProperties.

        The type of roomcompensation used / to use. simple:   For speakers without external speakers. advanced:   For products with external speakers or other advanced multichannel capabilities.   This requries that at least action in the other properties of RoomCompensationProperties is set.   # noqa: E501

        :param value: The value of this RoomCompensationProperties.  # noqa: E501
        :type value: 'RoomCompensationProperties.LTypeValue'
        :rtype: None
        """
        allowed_values = ["simple", "advanced"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and value not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `value` ({0}), must be one of {1}".format(  # noqa: E501
                    value, allowed_values
                )
            )

        self._value = value

    @property
    def action(self):
        # type: () -> str
        """Gets the action of this RoomCompensationProperties.  # noqa: E501

        Must be set if room compensation type is advanced. runAll:   Do measurements on all connected speakers. continue:   Continue from and including the speaker where last interrupted (stopped or failed). useSpeakerList:   Do measurements on the speakers in the list property.   # noqa: E501

        :return: The action of this RoomCompensationProperties.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        # type: (str) -> None
        """Sets the action of this RoomCompensationProperties.

        Must be set if room compensation type is advanced. runAll:   Do measurements on all connected speakers. continue:   Continue from and including the speaker where last interrupted (stopped or failed). useSpeakerList:   Do measurements on the speakers in the list property.   # noqa: E501

        :param action: The action of this RoomCompensationProperties.  # noqa: E501
        :type action: str
        :rtype: None
        """
        allowed_values = [None, "runAll", "continue", "useSpeakerList"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and action not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}".format(  # noqa: E501
                    action, allowed_values
                )
            )

        self._action = action

    @property
    def continue_on_error(self):
        # type: () -> bool
        """Gets the continue_on_error of this RoomCompensationProperties.  # noqa: E501

        On failing measurement on a speaker, default behavior is to stop measurement and skip the remaining speakers. Setting continueOnError to true will make the measuremnt process continue and finish measurement on all speakers, even though an error ocurred on one of the speakers.   # noqa: E501

        :return: The continue_on_error of this RoomCompensationProperties.  # noqa: E501
        :rtype: bool
        """
        return self._continue_on_error

    @continue_on_error.setter
    def continue_on_error(self, continue_on_error):
        # type: (bool) -> None
        """Sets the continue_on_error of this RoomCompensationProperties.

        On failing measurement on a speaker, default behavior is to stop measurement and skip the remaining speakers. Setting continueOnError to true will make the measuremnt process continue and finish measurement on all speakers, even though an error ocurred on one of the speakers.   # noqa: E501

        :param continue_on_error: The continue_on_error of this RoomCompensationProperties.  # noqa: E501
        :type continue_on_error: bool
        :rtype: None
        """

        self._continue_on_error = continue_on_error

    @property
    def skip_automatic_role_assignment(self):
        # type: () -> bool
        """Gets the skip_automatic_role_assignment of this RoomCompensationProperties.  # noqa: E501

        Skip calculation of automatic role assignment.  # noqa: E501

        :return: The skip_automatic_role_assignment of this RoomCompensationProperties.  # noqa: E501
        :rtype: bool
        """
        return self._skip_automatic_role_assignment

    @skip_automatic_role_assignment.setter
    def skip_automatic_role_assignment(self, skip_automatic_role_assignment):
        # type: (bool) -> None
        """Sets the skip_automatic_role_assignment of this RoomCompensationProperties.

        Skip calculation of automatic role assignment.  # noqa: E501

        :param skip_automatic_role_assignment: The skip_automatic_role_assignment of this RoomCompensationProperties.  # noqa: E501
        :type skip_automatic_role_assignment: bool
        :rtype: None
        """

        self._skip_automatic_role_assignment = skip_automatic_role_assignment

    @property
    def speaker_list(self):
        # type: () -> List[str]
        """Gets the speaker_list of this RoomCompensationProperties.  # noqa: E501

        List of speaker IDs to include in room compensation / automatic role assignment measurement. Relevant e.g. if you want to create a speaker group without the external speakers included. This can not be used for doing measurements on a partial speaker group, only on all speakers in an existing group or for all speakers in a new group.   # noqa: E501

        :return: The speaker_list of this RoomCompensationProperties.  # noqa: E501
        :rtype: List[str]
        """
        return self._speaker_list

    @speaker_list.setter
    def speaker_list(self, speaker_list):
        # type: (list[str]) -> None
        """Sets the speaker_list of this RoomCompensationProperties.

        List of speaker IDs to include in room compensation / automatic role assignment measurement. Relevant e.g. if you want to create a speaker group without the external speakers included. This can not be used for doing measurements on a partial speaker group, only on all speakers in an existing group or for all speakers in a new group.   # noqa: E501

        :param speaker_list: The speaker_list of this RoomCompensationProperties.  # noqa: E501
        :type speaker_list: list[str]
        :rtype: None
        """

        self._speaker_list = speaker_list

    @property
    def speaker_preset(self):
        # type: () -> int
        """Gets the speaker_preset of this RoomCompensationProperties.  # noqa: E501

        The Powerlink preset to use for the external PL/WPL speakers.  # noqa: E501

        :return: The speaker_preset of this RoomCompensationProperties.  # noqa: E501
        :rtype: int
        """
        return self._speaker_preset

    @speaker_preset.setter
    def speaker_preset(self, speaker_preset):
        # type: (int) -> None
        """Sets the speaker_preset of this RoomCompensationProperties.

        The Powerlink preset to use for the external PL/WPL speakers.  # noqa: E501

        :param speaker_preset: The speaker_preset of this RoomCompensationProperties.  # noqa: E501
        :type speaker_preset: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and speaker_preset is not None
            and speaker_preset > 255
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `speaker_preset`, must be a value less than or equal to `255`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and speaker_preset is not None
            and speaker_preset < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `speaker_preset`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._speaker_preset = speaker_preset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.playback_content_metadata import PlaybackContentMetadata
from mozart_api.models.source import Source
from mozart_api.models.rendering_state import RenderingState
from mozart_api.models.playback_progress import PlaybackProgress

from mozart_api.configuration import Configuration


class PlaybackState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "metadata": "PlaybackContentMetadata",
        "progress": "PlaybackProgress",
        "source": "Source",
        "state": "RenderingState",
    }

    attribute_map = {
        "metadata": "metadata",
        "progress": "progress",
        "source": "source",
        "state": "state",
    }

    def __init__(
        self,
        metadata: Optional[PlaybackContentMetadata] = None,
        progress: Optional[PlaybackProgress] = None,
        source: Optional[Source] = None,
        state: Optional[RenderingState] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PlaybackState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._metadata = None
        self._progress = None
        self._source = None
        self._state = None
        self.discriminator = None

        if metadata is not None:
            self.metadata = metadata
        if progress is not None:
            self.progress = progress
        if source is not None:
            self.source = source
        if state is not None:
            self.state = state

    @property
    def metadata(self):
        # type: () -> PlaybackContentMetadata
        """Gets the metadata of this PlaybackState.  # noqa: E501


        :return: The metadata of this PlaybackState.  # noqa: E501
        :rtype: PlaybackContentMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        # type: (PlaybackContentMetadata) -> None
        """Sets the metadata of this PlaybackState.


        :param metadata: The metadata of this PlaybackState.  # noqa: E501
        :type metadata: PlaybackContentMetadata
        :rtype: None
        """

        self._metadata = metadata

    @property
    def progress(self):
        # type: () -> PlaybackProgress
        """Gets the progress of this PlaybackState.  # noqa: E501


        :return: The progress of this PlaybackState.  # noqa: E501
        :rtype: PlaybackProgress
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        # type: (PlaybackProgress) -> None
        """Sets the progress of this PlaybackState.


        :param progress: The progress of this PlaybackState.  # noqa: E501
        :type progress: PlaybackProgress
        :rtype: None
        """

        self._progress = progress

    @property
    def source(self):
        # type: () -> Source
        """Gets the source of this PlaybackState.  # noqa: E501


        :return: The source of this PlaybackState.  # noqa: E501
        :rtype: Source
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (Source) -> None
        """Sets the source of this PlaybackState.


        :param source: The source of this PlaybackState.  # noqa: E501
        :type source: Source
        :rtype: None
        """

        self._source = source

    @property
    def state(self):
        # type: () -> RenderingState
        """Gets the state of this PlaybackState.  # noqa: E501


        :return: The state of this PlaybackState.  # noqa: E501
        :rtype: RenderingState
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: (RenderingState) -> None
        """Sets the state of this PlaybackState.


        :param state: The state of this PlaybackState.  # noqa: E501
        :type state: RenderingState
        :rtype: None
        """

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybackState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlaybackState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.tone_touch_type import ToneTouchType

from mozart_api.configuration import Configuration


class ToneTouch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"x": "ToneTouchType", "y": "ToneTouchType"}

    attribute_map = {"x": "x", "y": "y"}

    def __init__(
        self,
        x: Optional[ToneTouchType] = None,
        y: Optional[ToneTouchType] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ToneTouch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._x = None
        self._y = None
        self.discriminator = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def x(self):
        # type: () -> ToneTouchType
        """Gets the x of this ToneTouch.  # noqa: E501


        :return: The x of this ToneTouch.  # noqa: E501
        :rtype: ToneTouchType
        """
        return self._x

    @x.setter
    def x(self, x):
        # type: (ToneTouchType) -> None
        """Sets the x of this ToneTouch.


        :param x: The x of this ToneTouch.  # noqa: E501
        :type x: ToneTouchType
        :rtype: None
        """

        self._x = x

    @property
    def y(self):
        # type: () -> ToneTouchType
        """Gets the y of this ToneTouch.  # noqa: E501


        :return: The y of this ToneTouch.  # noqa: E501
        :rtype: ToneTouchType
        """
        return self._y

    @y.setter
    def y(self, y):
        # type: (ToneTouchType) -> None
        """Sets the y of this ToneTouch.


        :param y: The y of this ToneTouch.  # noqa: E501
        :type y: ToneTouchType
        :rtype: None
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ToneTouch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ToneTouch):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.beolink_experience import BeolinkExperience

from mozart_api.configuration import Configuration


class BeolinkExperiencesResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "experiences": "list[BeolinkExperience]",
        "request_id": "str",
        "status": "str",
    }

    attribute_map = {
        "experiences": "experiences",
        "request_id": "requestID",
        "status": "status",
    }

    def __init__(
        self,
        experiences: Optional[List[BeolinkExperience]] = None,
        request_id: Optional[str] = None,
        status: Optional["BeolinkExperiencesResult.LTypeStatus"] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """BeolinkExperiencesResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._experiences = None
        self._request_id = None
        self._status = None
        self.discriminator = None

        self.experiences = experiences
        self.request_id = request_id
        self.status = status

    @property
    def experiences(self):
        # type: () -> List[BeolinkExperience]
        """Gets the experiences of this BeolinkExperiencesResult.  # noqa: E501


        :return: The experiences of this BeolinkExperiencesResult.  # noqa: E501
        :rtype: List[BeolinkExperience]
        """
        return self._experiences

    @experiences.setter
    def experiences(self, experiences):
        # type: (list[BeolinkExperience]) -> None
        """Sets the experiences of this BeolinkExperiencesResult.


        :param experiences: The experiences of this BeolinkExperiencesResult.  # noqa: E501
        :type experiences: list[BeolinkExperience]
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and experiences is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `experiences`, must not be `None`"
            )  # noqa: E501

        self._experiences = experiences

    @property
    def request_id(self):
        # type: () -> str
        """Gets the request_id of this BeolinkExperiencesResult.  # noqa: E501

        Beolink request ID  # noqa: E501

        :return: The request_id of this BeolinkExperiencesResult.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        # type: (str) -> None
        """Sets the request_id of this BeolinkExperiencesResult.

        Beolink request ID  # noqa: E501

        :param request_id: The request_id of this BeolinkExperiencesResult.  # noqa: E501
        :type request_id: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and request_id is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `request_id`, must not be `None`"
            )  # noqa: E501

        self._request_id = request_id

    LTypeStatus = Literal["ok", "busy", "timeout"]

    @property
    def status(self):
        # type: () -> 'BeolinkExperiencesResult.LTypeStatus'
        """Gets the status of this BeolinkExperiencesResult.  # noqa: E501

        Current scan status. * busy: there is another scan in progress * timeout: the scan timed out. The results will be partial   # noqa: E501

        :return: The status of this BeolinkExperiencesResult.  # noqa: E501
        :rtype: 'BeolinkExperiencesResult.LTypeStatus'
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: ('BeolinkExperiencesResult.LTypeStatus') -> None
        """Sets the status of this BeolinkExperiencesResult.

        Current scan status. * busy: there is another scan in progress * timeout: the scan timed out. The results will be partial   # noqa: E501

        :param status: The status of this BeolinkExperiencesResult.  # noqa: E501
        :type status: 'BeolinkExperiencesResult.LTypeStatus'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and status is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["ok", "busy", "timeout"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and status not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BeolinkExperiencesResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BeolinkExperiencesResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.action import Action

from mozart_api.configuration import Configuration


class RemoteMenuItemProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "action_list": "list[Action]",
        "scene_list": "list[str]",
        "disabled": "bool",
        "dynamic_list": "str",
        "first_child_menu_item_id": "str",
        "label": "str",
        "next_sibling_menu_item_id": "str",
        "parent_menu_item_id": "str",
    }

    attribute_map = {
        "action_list": "actionList",
        "scene_list": "sceneList",
        "disabled": "disabled",
        "dynamic_list": "dynamicList",
        "first_child_menu_item_id": "firstChildMenuItemId",
        "label": "label",
        "next_sibling_menu_item_id": "nextSiblingMenuItemId",
        "parent_menu_item_id": "parentMenuItemId",
    }

    def __init__(
        self,
        action_list: Optional[List[Action]] = None,
        scene_list: Optional[List[str]] = None,
        disabled: Optional[bool] = None,
        dynamic_list: Optional[str] = None,
        first_child_menu_item_id: Optional[str] = None,
        label: Optional[str] = None,
        next_sibling_menu_item_id: Optional[str] = None,
        parent_menu_item_id: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RemoteMenuItemProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_list = None
        self._scene_list = None
        self._disabled = None
        self._dynamic_list = None
        self._first_child_menu_item_id = None
        self._label = None
        self._next_sibling_menu_item_id = None
        self._parent_menu_item_id = None
        self.discriminator = None

        if action_list is not None:
            self.action_list = action_list
        if scene_list is not None:
            self.scene_list = scene_list
        self.disabled = disabled
        self.dynamic_list = dynamic_list
        self.first_child_menu_item_id = first_child_menu_item_id
        self.label = label
        self.next_sibling_menu_item_id = next_sibling_menu_item_id
        self.parent_menu_item_id = parent_menu_item_id

    @property
    def action_list(self):
        # type: () -> List[Action]
        """Gets the action_list of this RemoteMenuItemProperties.  # noqa: E501

        An ordered list of Actions to run on the product  # noqa: E501

        :return: The action_list of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: List[Action]
        """
        return self._action_list

    @action_list.setter
    def action_list(self, action_list):
        # type: (list[Action]) -> None
        """Sets the action_list of this RemoteMenuItemProperties.

        An ordered list of Actions to run on the product  # noqa: E501

        :param action_list: The action_list of this RemoteMenuItemProperties.  # noqa: E501
        :type action_list: list[Action]
        :rtype: None
        """

        self._action_list = action_list

    @property
    def scene_list(self):
        # type: () -> List[str]
        """Gets the scene_list of this RemoteMenuItemProperties.  # noqa: E501

        A list of scenes  # noqa: E501

        :return: The scene_list of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: List[str]
        """
        return self._scene_list

    @scene_list.setter
    def scene_list(self, scene_list):
        # type: (list[str]) -> None
        """Sets the scene_list of this RemoteMenuItemProperties.

        A list of scenes  # noqa: E501

        :param scene_list: The scene_list of this RemoteMenuItemProperties.  # noqa: E501
        :type scene_list: list[str]
        :rtype: None
        """

        self._scene_list = scene_list

    @property
    def disabled(self):
        # type: () -> bool
        """Gets the disabled of this RemoteMenuItemProperties.  # noqa: E501


        :return: The disabled of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        # type: (bool) -> None
        """Sets the disabled of this RemoteMenuItemProperties.


        :param disabled: The disabled of this RemoteMenuItemProperties.  # noqa: E501
        :type disabled: bool
        :rtype: None
        """

        self._disabled = disabled

    @property
    def dynamic_list(self):
        # type: () -> str
        """Gets the dynamic_list of this RemoteMenuItemProperties.  # noqa: E501

        Let mozart create a dynamic list. This list will be attached as children to the menu item. If dynamicList is set it's not possible to change or manipulate any of the children because mozart can alter them at any given time   # noqa: E501

        :return: The dynamic_list of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_list

    @dynamic_list.setter
    def dynamic_list(self, dynamic_list):
        # type: (str) -> None
        """Sets the dynamic_list of this RemoteMenuItemProperties.

        Let mozart create a dynamic list. This list will be attached as children to the menu item. If dynamicList is set it's not possible to change or manipulate any of the children because mozart can alter them at any given time   # noqa: E501

        :param dynamic_list: The dynamic_list of this RemoteMenuItemProperties.  # noqa: E501
        :type dynamic_list: str
        :rtype: None
        """
        allowed_values = [None, "none", "radioFavorites"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and dynamic_list not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `dynamic_list` ({0}), must be one of {1}".format(  # noqa: E501
                    dynamic_list, allowed_values
                )
            )

        self._dynamic_list = dynamic_list

    @property
    def first_child_menu_item_id(self):
        # type: () -> str
        """Gets the first_child_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501

        ID of the first child menu item  # noqa: E501

        :return: The first_child_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: str
        """
        return self._first_child_menu_item_id

    @first_child_menu_item_id.setter
    def first_child_menu_item_id(self, first_child_menu_item_id):
        # type: (str) -> None
        """Sets the first_child_menu_item_id of this RemoteMenuItemProperties.

        ID of the first child menu item  # noqa: E501

        :param first_child_menu_item_id: The first_child_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :type first_child_menu_item_id: str
        :rtype: None
        """

        self._first_child_menu_item_id = first_child_menu_item_id

    @property
    def label(self):
        # type: () -> str
        """Gets the label of this RemoteMenuItemProperties.  # noqa: E501

        Alternative label, if omitted mozart will try its best  # noqa: E501

        :return: The label of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        # type: (str) -> None
        """Sets the label of this RemoteMenuItemProperties.

        Alternative label, if omitted mozart will try its best  # noqa: E501

        :param label: The label of this RemoteMenuItemProperties.  # noqa: E501
        :type label: str
        :rtype: None
        """

        self._label = label

    @property
    def next_sibling_menu_item_id(self):
        # type: () -> str
        """Gets the next_sibling_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501

        ID of the next sibling menu item  # noqa: E501

        :return: The next_sibling_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: str
        """
        return self._next_sibling_menu_item_id

    @next_sibling_menu_item_id.setter
    def next_sibling_menu_item_id(self, next_sibling_menu_item_id):
        # type: (str) -> None
        """Sets the next_sibling_menu_item_id of this RemoteMenuItemProperties.

        ID of the next sibling menu item  # noqa: E501

        :param next_sibling_menu_item_id: The next_sibling_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :type next_sibling_menu_item_id: str
        :rtype: None
        """

        self._next_sibling_menu_item_id = next_sibling_menu_item_id

    @property
    def parent_menu_item_id(self):
        # type: () -> str
        """Gets the parent_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501

        ID of the parent menu item  # noqa: E501

        :return: The parent_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :rtype: str
        """
        return self._parent_menu_item_id

    @parent_menu_item_id.setter
    def parent_menu_item_id(self, parent_menu_item_id):
        # type: (str) -> None
        """Sets the parent_menu_item_id of this RemoteMenuItemProperties.

        ID of the parent menu item  # noqa: E501

        :param parent_menu_item_id: The parent_menu_item_id of this RemoteMenuItemProperties.  # noqa: E501
        :type parent_menu_item_id: str
        :rtype: None
        """

        self._parent_menu_item_id = parent_menu_item_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteMenuItemProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoteMenuItemProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class VideoTimings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "horizontal_resolution": "int",
        "interlaced": "bool",
        "refresh_rate": "float",
        "vertical_resolution": "int",
    }

    attribute_map = {
        "horizontal_resolution": "horizontalResolution",
        "interlaced": "interlaced",
        "refresh_rate": "refreshRate",
        "vertical_resolution": "verticalResolution",
    }

    def __init__(
        self,
        horizontal_resolution: Optional[int] = None,
        interlaced: Optional[bool] = None,
        refresh_rate: Optional[float] = None,
        vertical_resolution: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """VideoTimings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._horizontal_resolution = None
        self._interlaced = None
        self._refresh_rate = None
        self._vertical_resolution = None
        self.discriminator = None

        if horizontal_resolution is not None:
            self.horizontal_resolution = horizontal_resolution
        if interlaced is not None:
            self.interlaced = interlaced
        if refresh_rate is not None:
            self.refresh_rate = refresh_rate
        if vertical_resolution is not None:
            self.vertical_resolution = vertical_resolution

    @property
    def horizontal_resolution(self):
        # type: () -> int
        """Gets the horizontal_resolution of this VideoTimings.  # noqa: E501


        :return: The horizontal_resolution of this VideoTimings.  # noqa: E501
        :rtype: int
        """
        return self._horizontal_resolution

    @horizontal_resolution.setter
    def horizontal_resolution(self, horizontal_resolution):
        # type: (int) -> None
        """Sets the horizontal_resolution of this VideoTimings.


        :param horizontal_resolution: The horizontal_resolution of this VideoTimings.  # noqa: E501
        :type horizontal_resolution: int
        :rtype: None
        """

        self._horizontal_resolution = horizontal_resolution

    @property
    def interlaced(self):
        # type: () -> bool
        """Gets the interlaced of this VideoTimings.  # noqa: E501


        :return: The interlaced of this VideoTimings.  # noqa: E501
        :rtype: bool
        """
        return self._interlaced

    @interlaced.setter
    def interlaced(self, interlaced):
        # type: (bool) -> None
        """Sets the interlaced of this VideoTimings.


        :param interlaced: The interlaced of this VideoTimings.  # noqa: E501
        :type interlaced: bool
        :rtype: None
        """

        self._interlaced = interlaced

    @property
    def refresh_rate(self):
        # type: () -> float
        """Gets the refresh_rate of this VideoTimings.  # noqa: E501


        :return: The refresh_rate of this VideoTimings.  # noqa: E501
        :rtype: float
        """
        return self._refresh_rate

    @refresh_rate.setter
    def refresh_rate(self, refresh_rate):
        # type: (float) -> None
        """Sets the refresh_rate of this VideoTimings.


        :param refresh_rate: The refresh_rate of this VideoTimings.  # noqa: E501
        :type refresh_rate: float
        :rtype: None
        """

        self._refresh_rate = refresh_rate

    @property
    def vertical_resolution(self):
        # type: () -> int
        """Gets the vertical_resolution of this VideoTimings.  # noqa: E501


        :return: The vertical_resolution of this VideoTimings.  # noqa: E501
        :rtype: int
        """
        return self._vertical_resolution

    @vertical_resolution.setter
    def vertical_resolution(self, vertical_resolution):
        # type: (int) -> None
        """Sets the vertical_resolution of this VideoTimings.


        :param vertical_resolution: The vertical_resolution of this VideoTimings.  # noqa: E501
        :type vertical_resolution: int
        :rtype: None
        """

        self._vertical_resolution = vertical_resolution

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoTimings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoTimings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.action import Action  # noqa: E501
from mozart_api.rest import ApiException


class TestAction(unittest.TestCase):
    """Action unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Action
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.action.Action()  # noqa: E501
        if include_optional:
            return Action(
                button_name="preset1",
                content_id="0",
                deezer_user_id="0",
                listening_mode_id=0,
                preset_key="0",
                queue_item=mozart_api.models.play_queue_item.PlayQueueItem(
                    index=56,
                    metadata=mozart_api.models.playback_content_metadata.PlaybackContentMetadata(
                        album_name="0",
                        art=[
                            mozart_api.models.art.Art(
                                has_local_image=True,
                                key="0",
                                size="0",
                                type="0",
                                url="0",
                            )
                        ],
                        artist_name="0",
                        bitdepth=56,
                        bitrate=56,
                        container_name="0",
                        encoding="pcm",
                        genre="0",
                        id=56,
                        input_channel_processing="dolbySurround",
                        input_channels="0",
                        organization="0",
                        output_channel_processing="Direct",
                        output_channels="0",
                        queue_id="0",
                        remote_leader=mozart_api.models.beolink_leader.BeolinkLeader(
                            friendly_name="0",
                            jid="2714.1200304.26451293@products.bang-olufsen.com",
                        ),
                        remote_source="0",
                        samplerate=56,
                        source="0",
                        source_internal_id="0",
                        title="0",
                        total_duration=56,
                        total_duration_seconds=56,
                        track=56,
                        track_count=56,
                        uri="0",
                    ),
                    provider=mozart_api.models.play_queue_item_type.PlayQueueItemType(
                        value="uri",
                    ),
                    start_now_from_position=56,
                    type="track",
                    uri="0",
                ),
                queue_settings=mozart_api.models.play_queue_settings.PlayQueueSettings(
                    consume=True,
                    gapless=True,
                    repeat="all",
                    shuffle=True,
                ),
                radio_station_id="0",
                source=mozart_api.models.source_type_enum.SourceTypeEnum(
                    value="beolink",
                ),
                speaker_group_id="0",
                stand_position=mozart_api.models.stand_position.StandPosition(
                    angle=1.337,
                ),
                stop_duration=0,
                tone_name="alarm_1",
                type="standby",
                volume_level=0,
            )
        else:
            return Action(
                type="standby",
            )

    def testAction(self):
        """Test Action"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.mozart_api import MozartApi  # noqa: E501
from mozart_api.rest import ApiException


class TestMozartApi(unittest.TestCase):
    """MozartApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.mozart_api.MozartApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_listening_mode(self):
        """Test case for activate_listening_mode

        Activate a listening mode  # noqa: E501
        """
        pass

    def test_activate_preset(self):
        """Test case for activate_preset

        Trigger a preset  # noqa: E501
        """
        pass

    def test_add_to_queue(self):
        """Test case for add_to_queue

        Add an element to the queue  # noqa: E501
        """
        pass

    def test_get_active_listening_mode(self):
        """Test case for get_active_listening_mode

        Get the active listening mode  # noqa: E501
        """
        pass

    def test_get_all_scenes(self):
        """Test case for get_all_scenes

        Get a list of configured scenes  # noqa: E501
        """
        pass

    def test_get_available_sources(self):
        """Test case for get_available_sources

        Get all the available sources  # noqa: E501
        """
        pass

    def test_get_battery_state(self):
        """Test case for get_battery_state

        Get battery state of the product  # noqa: E501
        """
        pass

    def test_get_beolink_available_listeners(self):
        """Test case for get_beolink_available_listeners

        Get available listeners  # noqa: E501
        """
        pass

    def test_get_beolink_join_result(self):
        """Test case for get_beolink_join_result

        Get Beolink join result, test-endpoint  # noqa: E501
        """
        pass

    def test_get_beolink_listeners(self):
        """Test case for get_beolink_listeners

        Get joined peers  # noqa: E501
        """
        pass

    def test_get_beolink_peers(self):
        """Test case for get_beolink_peers

        Get discovered peers  # noqa: E501
        """
        pass

    def test_get_beolink_self(self):
        """Test case for get_beolink_self

        Get information about this device  # noqa: E501
        """
        pass

    def test_get_bluetooth_devices_status(self):
        """Test case for get_bluetooth_devices_status

        Get the bluetooth devices status  # noqa: E501
        """
        pass

    def test_get_bluetooth_remotes(self):
        """Test case for get_bluetooth_remotes

        Get a list of paired bluetooth remotes  # noqa: E501
        """
        pass

    def test_get_content(self):
        """Test case for get_content

        Get a list of available content  # noqa: E501
        """
        pass

    def test_get_current_volume(self):
        """Test case for get_current_volume

        Get the current volume state  # noqa: E501
        """
        pass

    def test_get_listening_mode_set(self):
        """Test case for get_listening_mode_set

        Get available listening modes that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_playback_state(self):
        """Test case for get_playback_state

        Get the current playback state  # noqa: E501
        """
        pass

    def test_get_power_state(self):
        """Test case for get_power_state

        Get power state of the product  # noqa: E501
        """
        pass

    def test_get_presets(self):
        """Test case for get_presets

        Get the preset configuration  # noqa: E501
        """
        pass

    def test_get_product_state(self):
        """Test case for get_product_state

        Get the overall state from the product  # noqa: E501
        """
        pass

    def test_get_remote_home_control_uri(self):
        """Test case for get_remote_home_control_uri

        Get the HomeControl dashboard URI  # noqa: E501
        """
        pass

    def test_get_remote_menu(self):
        """Test case for get_remote_menu

        Get all remote menu items  # noqa: E501
        """
        pass

    def test_get_settings_queue(self):
        """Test case for get_settings_queue

        Get the current queue settings  # noqa: E501
        """
        pass

    def test_get_softwareupdate_status(self):
        """Test case for get_softwareupdate_status

        Get the current software update status  # noqa: E501
        """
        pass

    def test_get_sound_features(self):
        """Test case for get_sound_features

        Get available sound features that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_speakergroup_active(self):
        """Test case for get_speakergroup_active

        Get the active speaker group  # noqa: E501
        """
        pass

    def test_get_volume_settings(self):
        """Test case for get_volume_settings

        Get the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass

    def test_join_beolink_peer(self):
        """Test case for join_beolink_peer

        Join multi-room experience  # noqa: E501
        """
        pass

    def test_join_latest_beolink_experience(self):
        """Test case for join_latest_beolink_experience

        Trigger touch to join  # noqa: E501
        """
        pass

    def test_post_beolink_allstandby(self):
        """Test case for post_beolink_allstandby

        Broadcast an all standby event to turn all Beolink devices off  # noqa: E501
        """
        pass

    def test_post_beolink_expand(self):
        """Test case for post_beolink_expand

        Expand the current active experience  # noqa: E501
        """
        pass

    def test_post_beolink_leave(self):
        """Test case for post_beolink_leave

        Leave the ongoing experience (disconnect this device from remote)  # noqa: E501
        """
        pass

    def test_post_beolink_unexpand(self):
        """Test case for post_beolink_unexpand

        Unexpand (disconnect) a device from the multiroom session  # noqa: E501
        """
        pass

    def test_post_clear_queue(self):
        """Test case for post_clear_queue

        Clear the queue  # noqa: E501
        """
        pass

    def test_post_overlay_play(self):
        """Test case for post_overlay_play

        Play overlay  # noqa: E501
        """
        pass

    def test_post_playback_command(self):
        """Test case for post_playback_command

        Send a specific playback command to the product  # noqa: E501
        """
        pass

    def test_post_remote_key_trigger(self):
        """Test case for post_remote_key_trigger

        Remote input key press  # noqa: E501
        """
        pass

    def test_post_remote_trigger(self):
        """Test case for post_remote_trigger

        Trigger a remote menu item  # noqa: E501
        """
        pass

    def test_post_scene_match_trigger(self):
        """Test case for post_scene_match_trigger

        Trigger the first scene with same non null objects provided in the SceneMatch object  # noqa: E501
        """
        pass

    def test_post_scene_trigger(self):
        """Test case for post_scene_trigger

        Trigger a specific scene  # noqa: E501
        """
        pass

    def test_post_standby(self):
        """Test case for post_standby

        Put the device in standby  # noqa: E501
        """
        pass

    def test_post_uri_source(self):
        """Test case for post_uri_source

        Set the URI from which sound is streamed  # noqa: E501
        """
        pass

    def test_run_provided_scene(self):
        """Test case for run_provided_scene

        Run provided scene  # noqa: E501
        """
        pass

    def test_seek_to_position(self):
        """Test case for seek_to_position

        Seek to position in stream  # noqa: E501
        """
        pass

    def test_set_active_source(self):
        """Test case for set_active_source

        Set the active source  # noqa: E501
        """
        pass

    def test_set_current_volume_level(self):
        """Test case for set_current_volume_level

        Set the current volume level  # noqa: E501
        """
        pass

    def test_set_product_friendly_name(self):
        """Test case for set_product_friendly_name

        Set the friendly name  # noqa: E501
        """
        pass

    def test_set_remote_home_control_uri(self):
        """Test case for set_remote_home_control_uri

        Set the HomeControl dashboard URI  # noqa: E501
        """
        pass

    def test_set_settings_queue(self):
        """Test case for set_settings_queue

        Set queue settings  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_bass(self):
        """Test case for set_sound_settings_adjustments_bass

        Update the sound settings adjustments for bass  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_directivity(self):
        """Test case for set_sound_settings_adjustments_directivity

        Update the sound settings adjustments for directivity  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_loudness(self):
        """Test case for set_sound_settings_adjustments_loudness

        Update the sound settings adjustments for loudness  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_treble(self):
        """Test case for set_sound_settings_adjustments_treble

        Update the sound settings adjustments for treble  # noqa: E501
        """
        pass

    def test_set_volume_mute(self):
        """Test case for set_volume_mute

        Set the volume mute state  # noqa: E501
        """
        pass

    def test_set_volume_settings(self):
        """Test case for set_volume_settings

        Set the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass

    def test_start_deezer_flow(self):
        """Test case for start_deezer_flow

        Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class BeolinkExperience(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "category": "str",
        "id": "str",
        "linkable": "bool",
        "name": "str",
        "product_friendly_name": "str",
        "source_friendly_name": "str",
        "type": "str",
        "unique_source_id": "str",
    }

    attribute_map = {
        "category": "category",
        "id": "id",
        "linkable": "linkable",
        "name": "name",
        "product_friendly_name": "productFriendlyName",
        "source_friendly_name": "sourceFriendlyName",
        "type": "type",
        "unique_source_id": "uniqueSourceId",
    }

    def __init__(
        self,
        category: Optional["BeolinkExperience.LTypeCategory"] = None,
        id: Optional[str] = None,
        linkable: Optional[bool] = None,
        name: Optional[str] = None,
        product_friendly_name: Optional[str] = None,
        source_friendly_name: Optional[str] = None,
        type: Optional[str] = None,
        unique_source_id: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """BeolinkExperience - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category = None
        self._id = None
        self._linkable = None
        self._name = None
        self._product_friendly_name = None
        self._source_friendly_name = None
        self._type = None
        self._unique_source_id = None
        self.discriminator = None

        self.category = category
        self.id = id
        self.linkable = linkable
        self.name = name
        if product_friendly_name is not None:
            self.product_friendly_name = product_friendly_name
        if source_friendly_name is not None:
            self.source_friendly_name = source_friendly_name
        self.type = type
        self.unique_source_id = unique_source_id

    LTypeCategory = Literal["TV", "RADIO", "MUSIC", "MEDIA", "UNKNOWN"]

    @property
    def category(self):
        # type: () -> 'BeolinkExperience.LTypeCategory'
        """Gets the category of this BeolinkExperience.  # noqa: E501

        Source category  # noqa: E501

        :return: The category of this BeolinkExperience.  # noqa: E501
        :rtype: 'BeolinkExperience.LTypeCategory'
        """
        return self._category

    @category.setter
    def category(self, category):
        # type: ('BeolinkExperience.LTypeCategory') -> None
        """Sets the category of this BeolinkExperience.

        Source category  # noqa: E501

        :param category: The category of this BeolinkExperience.  # noqa: E501
        :type category: 'BeolinkExperience.LTypeCategory'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and category is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `category`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["TV", "RADIO", "MUSIC", "MEDIA", "UNKNOWN"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and category not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}".format(  # noqa: E501
                    category, allowed_values
                )
            )

        self._category = category

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this BeolinkExperience.  # noqa: E501

        experience id, e.g. \"RADIO\" or \"toslink\"  # noqa: E501

        :return: The id of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (str) -> None
        """Sets the id of this BeolinkExperience.

        experience id, e.g. \"RADIO\" or \"toslink\"  # noqa: E501

        :param id: The id of this BeolinkExperience.  # noqa: E501
        :type id: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and id is None
        ):  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def linkable(self):
        # type: () -> bool
        """Gets the linkable of this BeolinkExperience.  # noqa: E501

        Linkable means \"Does pressing play on this source make sense\"  # noqa: E501

        :return: The linkable of this BeolinkExperience.  # noqa: E501
        :rtype: bool
        """
        return self._linkable

    @linkable.setter
    def linkable(self, linkable):
        # type: (bool) -> None
        """Sets the linkable of this BeolinkExperience.

        Linkable means \"Does pressing play on this source make sense\"  # noqa: E501

        :param linkable: The linkable of this BeolinkExperience.  # noqa: E501
        :type linkable: bool
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and linkable is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `linkable`, must not be `None`"
            )  # noqa: E501

        self._linkable = linkable

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this BeolinkExperience.  # noqa: E501

        Experience name, e.g. \"Bluetooth\" or \"B&O Radio\"  # noqa: E501

        :return: The name of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (str) -> None
        """Sets the name of this BeolinkExperience.

        Experience name, e.g. \"Bluetooth\" or \"B&O Radio\"  # noqa: E501

        :param name: The name of this BeolinkExperience.  # noqa: E501
        :type name: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and name is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def product_friendly_name(self):
        # type: () -> str
        """Gets the product_friendly_name of this BeolinkExperience.  # noqa: E501

        Optional product friendly name  # noqa: E501

        :return: The product_friendly_name of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._product_friendly_name

    @product_friendly_name.setter
    def product_friendly_name(self, product_friendly_name):
        # type: (str) -> None
        """Sets the product_friendly_name of this BeolinkExperience.

        Optional product friendly name  # noqa: E501

        :param product_friendly_name: The product_friendly_name of this BeolinkExperience.  # noqa: E501
        :type product_friendly_name: str
        :rtype: None
        """

        self._product_friendly_name = product_friendly_name

    @property
    def source_friendly_name(self):
        # type: () -> str
        """Gets the source_friendly_name of this BeolinkExperience.  # noqa: E501

        Optional friendly name for source  # noqa: E501

        :return: The source_friendly_name of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._source_friendly_name

    @source_friendly_name.setter
    def source_friendly_name(self, source_friendly_name):
        # type: (str) -> None
        """Sets the source_friendly_name of this BeolinkExperience.

        Optional friendly name for source  # noqa: E501

        :param source_friendly_name: The source_friendly_name of this BeolinkExperience.  # noqa: E501
        :type source_friendly_name: str
        :rtype: None
        """

        self._source_friendly_name = source_friendly_name

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this BeolinkExperience.  # noqa: E501

        Source type. This corresponds to the exhaustive list or sources provided by the control layer  # noqa: E501

        :return: The type of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: (str) -> None
        """Sets the type of this BeolinkExperience.

        Source type. This corresponds to the exhaustive list or sources provided by the control layer  # noqa: E501

        :param type: The type of this BeolinkExperience.  # noqa: E501
        :type type: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and type is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501

        self._type = type

    @property
    def unique_source_id(self):
        # type: () -> str
        """Gets the unique_source_id of this BeolinkExperience.  # noqa: E501

        The actual device jabber id that the experience comes from  # noqa: E501

        :return: The unique_source_id of this BeolinkExperience.  # noqa: E501
        :rtype: str
        """
        return self._unique_source_id

    @unique_source_id.setter
    def unique_source_id(self, unique_source_id):
        # type: (str) -> None
        """Sets the unique_source_id of this BeolinkExperience.

        The actual device jabber id that the experience comes from  # noqa: E501

        :param unique_source_id: The unique_source_id of this BeolinkExperience.  # noqa: E501
        :type unique_source_id: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and unique_source_id is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `unique_source_id`, must not be `None`"
            )  # noqa: E501

        self._unique_source_id = unique_source_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BeolinkExperience):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BeolinkExperience):
            return True

        return self.to_dict() != other.to_dict()
